#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "esp_log.h"

#include "ssd1306.h"
#include "font8x8_basic.h"

/*
 You have to set this config value with menuconfig
 CONFIG_INTERFACE

 for i2c
 CONFIG_MODEL
 CONFIG_SDA_GPIO
 CONFIG_SCL_GPIO
 CONFIG_RESET_GPIO

 for SPI
 CONFIG_CS_GPIO
 CONFIG_DC_GPIO
 CONFIG_RESET_GPIO
*/

#define TAG "SSD1306"

// https://www.mischianti.org/2021/07/14/ssd1306-oled-display-draw-images-splash-and-animations-2/
uint8_t monkeyAnimation[10] [1024] = {
// 'monkey01, 64x128px
{   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x7f, 0x3f, 0xff, 0xff, 0xff,
0xff, 0xff, 0xfc, 0x7e, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x78, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf8, 0x70, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x20, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x70, 0x00, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xf0, 0x00, 0x00, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x3c, 0x7f, 0xff, 0xff,
0xff, 0xfc, 0x00, 0x00, 0x00, 0x1f, 0xff, 0xff, 0xff, 0xfe, 0x00, 0x20, 0x07, 0x8f, 0xff, 0xff,
0xff, 0xff, 0x01, 0xf8, 0x0f, 0xc7, 0xff, 0xff, 0xff, 0xff, 0x83, 0xfe, 0x1f, 0xe7, 0xff, 0xff,
0xff, 0xff, 0x87, 0xff, 0x1f, 0xe7, 0xff, 0xff, 0xff, 0xff, 0x87, 0xff, 0x3f, 0xe6, 0x07, 0xff,
0xff, 0xcf, 0x87, 0xff, 0xf9, 0xf0, 0xe3, 0xff, 0xff, 0x03, 0x07, 0xff, 0xf1, 0xf1, 0xf8, 0xff,
0xfc, 0x38, 0x07, 0xe1, 0xe0, 0xf3, 0xfc, 0xff, 0xf8, 0x78, 0x07, 0xe0, 0xe0, 0xf7, 0xf8, 0x7f,
0xf8, 0xfe, 0x07, 0xe0, 0xe0, 0x7f, 0x10, 0x7f, 0xf1, 0xde, 0x07, 0xe0, 0x60, 0x7e, 0x06, 0x7f,
0xf3, 0x8f, 0x03, 0xf0, 0x70, 0xfd, 0xee, 0x7f, 0xf3, 0x3f, 0x03, 0xf0, 0x70, 0x7d, 0xee, 0x7f,
0xe6, 0x3e, 0x0f, 0xe0, 0x70, 0x7d, 0xfe, 0x7f, 0xe6, 0x1f, 0x0f, 0xf0, 0x70, 0xfd, 0xfe, 0x7f,
0xe6, 0xcf, 0x1f, 0xf0, 0x78, 0xff, 0xfc, 0x7f, 0xe6, 0xff, 0x3f, 0xf8, 0xfd, 0xff, 0xfc, 0xff,
0xe7, 0xff, 0x3f, 0xf9, 0xff, 0xff, 0xf8, 0xff, 0xe7, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xf3, 0xff,
0xf7, 0xff, 0x7c, 0xff, 0xff, 0xff, 0xc7, 0xff, 0xf3, 0xff, 0x3e, 0x3f, 0xff, 0xff, 0x0f, 0xff,
0xf0, 0xfe, 0x3f, 0x07, 0xff, 0xfc, 0x3f, 0xff, 0xf8, 0x00, 0x3f, 0xc0, 0x38, 0x00, 0x7f, 0xff,
0xfc, 0x03, 0x1f, 0xfc, 0x00, 0x01, 0xff, 0xff, 0xff, 0xff, 0x9f, 0xff, 0x83, 0xe3, 0xff, 0xff,
0xff, 0xff, 0x8f, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xff, 0xff, 0xc7, 0xff, 0xff, 0xf3, 0xff, 0xfb,
0xff, 0xff, 0xe3, 0xff, 0xff, 0xe7, 0xff, 0xc0, 0xff, 0xff, 0xe0, 0xff, 0xff, 0x87, 0xff, 0x86,
0xff, 0xff, 0xfc, 0x1f, 0xfe, 0x0f, 0xff, 0x9f, 0xff, 0xff, 0xff, 0x00, 0x30, 0x1f, 0xff, 0x3f,
0xff, 0xff, 0xf8, 0x00, 0x00, 0x0f, 0xff, 0x7f, 0xff, 0xfe, 0x00, 0x00, 0x00, 0x03, 0xff, 0x79,
0xff, 0xf8, 0x00, 0x00, 0x00, 0x03, 0xfe, 0x79, 0xff, 0x80, 0x00, 0x00, 0x00, 0x01, 0xfe, 0xf9,
0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0xe0, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x78,
0xfe, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0x7f, 0xfe, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7c, 0x7f,
0xfc, 0x00, 0x00, 0x00, 0x00, 0x01, 0x3e, 0x7f, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x01, 0x3e, 0x1f,
0xf8, 0x01, 0xff, 0x80, 0x00, 0x01, 0x8e, 0x00, 0xf8, 0x01, 0xff, 0x00, 0x00, 0x00, 0x0e, 0x00,
0xf8, 0x03, 0xfe, 0x00, 0x00, 0x01, 0x86, 0x01, 0xf8, 0x03, 0xfe, 0x00, 0x00, 0x00, 0x80, 0x00,
0xfc, 0x03, 0xfe, 0x00, 0x00, 0x00, 0xc0, 0x00, 0xf8, 0x01, 0xfe, 0x00, 0x00, 0x00, 0xc0, 0x00,
0xf2, 0x60, 0x7e, 0x00, 0x00, 0x00, 0x40, 0x03, 0xcf, 0xfe, 0x3e, 0x00, 0x00, 0x00, 0x60, 0x07,
0xdf, 0xff, 0x1e, 0x00, 0x00, 0x00, 0x60, 0x07, 0x9f, 0xff, 0x1e, 0x00, 0x00, 0x00, 0x60, 0x07,
0xbf, 0xff, 0x8e, 0x00, 0x00, 0x00, 0x70, 0x0f, 0x3f, 0xff, 0x0e, 0x00, 0x00, 0x00, 0x7c, 0x7f,
0x3f, 0xff, 0x0e, 0x00, 0x00, 0x00, 0x3f, 0xff, 0xbf, 0xff, 0x27, 0x00, 0x00, 0x00, 0x7f, 0xff,
0x3f, 0xff, 0x27, 0x00, 0x00, 0x00, 0x7f, 0xff, 0xbf, 0xff, 0x27, 0x80, 0x00, 0x80, 0x7f, 0xff,
0xbf, 0xff, 0x87, 0x80, 0x00, 0xe0, 0x7f, 0xff, 0x9f, 0xff, 0x83, 0xe0, 0x00, 0x70, 0x7c, 0x3f,
0x9b, 0xff, 0xc3, 0xf0, 0x00, 0x18, 0xfc, 0xbf, 0x9b, 0xff, 0xe7, 0xf8, 0x00, 0x0e, 0xfd, 0xa3,
0x89, 0xbf, 0xe7, 0xfc, 0x00, 0x03, 0xfd, 0x81, 0xc0, 0x4f, 0xc7, 0xfe, 0x00, 0x03, 0xfb, 0x9d,
0xfe, 0x0c, 0x0f, 0xff, 0x00, 0x00, 0xfb, 0x98, 0xfe, 0x00, 0x1f, 0xff, 0x80, 0x01, 0xf3, 0xb8,
0xff, 0x70, 0x1f, 0xff, 0xc0, 0x00, 0xf3, 0xb9, 0xff, 0xff, 0xff, 0xff, 0xe0, 0x00, 0x77, 0x3b,
0xff, 0xff, 0xf0, 0xff, 0x30, 0x00, 0x77, 0x73, 0xff, 0xff, 0xe0, 0x1e, 0x18, 0x00, 0x37, 0x73,
0xff, 0xff, 0x88, 0x00, 0x00, 0x00, 0x36, 0x77, 0xff, 0xff, 0x38, 0x00, 0x02, 0x00, 0x06, 0xe7,
0xff, 0xff, 0x30, 0x00, 0x03, 0x80, 0x07, 0xff, 0xff, 0xfe, 0x70, 0x00, 0x01, 0xc0, 0x07, 0xfe,
0xff, 0xfe, 0x78, 0x00, 0x01, 0xc0, 0x0f, 0xfc, 0xff, 0xfe, 0x7c, 0x00, 0x03, 0xe0, 0x0f, 0xfc,
0xff, 0xfc, 0x7e, 0x00, 0x07, 0xf0, 0x0f, 0xf8, 0xff, 0xfc, 0xff, 0x00, 0x0f, 0xf8, 0x0f, 0xf8,
0xff, 0xfc, 0xff, 0xc0, 0x07, 0xf8, 0x1f, 0xf8, 0xff, 0xfc, 0xff, 0xf3, 0x87, 0xfc, 0x3f, 0xf8,
0xff, 0xfc, 0xff, 0xff, 0xc3, 0xfe, 0x3f, 0xf9, 0xff, 0xfc, 0x7f, 0xff, 0xf1, 0xff, 0x3f, 0xf1,
0xff, 0xfe, 0x7f, 0xfe, 0x79, 0xff, 0x7f, 0xf3, 0xff, 0xfe, 0x7f, 0xfe, 0x31, 0xff, 0x7f, 0xf3,
0xff, 0xfe, 0x3f, 0xff, 0x03, 0xff, 0x3f, 0xe7, 0xff, 0xff, 0x1f, 0xe7, 0x03, 0xff, 0xbf, 0xe7,
0xff, 0xff, 0x8f, 0xe3, 0x3f, 0xff, 0x9f, 0xcf, 0xff, 0xff, 0x87, 0xf3, 0x3f, 0xff, 0x8f, 0x8f,
0xff, 0xff, 0xc0, 0xf0, 0x7f, 0xff, 0xc0, 0x3f, 0xff, 0xff, 0xf0, 0xf0, 0xff, 0xff, 0xf0, 0x7f,
0xff, 0xff, 0xf8, 0x03, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x03, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
},
// 'monkey02, 64x128px
{   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf8, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0xfc, 0x3f, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x60, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xff, 0xe0, 0x00, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe0, 0x00, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xfd, 0xc0, 0x00, 0x30, 0x3f, 0xff, 0xff, 0xff, 0xe0, 0x00, 0x00, 0x06, 0x1f, 0xff, 0xff,
0xff, 0xe0, 0x00, 0xf0, 0x1f, 0x9f, 0xff, 0xff, 0xff, 0xe0, 0x03, 0xf8, 0x3f, 0xcf, 0xff, 0xff,
0xff, 0xfb, 0x07, 0xfc, 0x3f, 0xcf, 0xff, 0xff, 0xff, 0xff, 0x8f, 0xff, 0x7f, 0xcf, 0xff, 0xff,
0xff, 0xff, 0x0f, 0xff, 0x7f, 0xce, 0x8f, 0xff, 0xff, 0xff, 0x0f, 0xff, 0xe7, 0xc8, 0x07, 0xff,
0xff, 0xff, 0x0f, 0xff, 0xe3, 0xc1, 0xe3, 0xff, 0xf8, 0x0e, 0x0f, 0xe7, 0xe1, 0xc3, 0xf9, 0xff,
0xf1, 0xe6, 0x0f, 0xc1, 0xe1, 0xe7, 0xf9, 0xff, 0xe3, 0xf8, 0x0f, 0xc1, 0xc1, 0xff, 0xf0, 0xff,
0xe7, 0xfc, 0x0f, 0xc0, 0xe0, 0xfe, 0x40, 0xff, 0xcf, 0x9e, 0x0f, 0xc0, 0xe0, 0xfc, 0x0c, 0xff,
0xcf, 0x1e, 0x0f, 0xc0, 0xe0, 0xfd, 0x8c, 0xff, 0xce, 0x7e, 0x1f, 0xc0, 0xe0, 0xf9, 0xcc, 0xff,
0xcc, 0x3e, 0x3f, 0xe0, 0xe0, 0xff, 0xfc, 0xff, 0xcd, 0x1e, 0x3f, 0xe0, 0xf0, 0xfb, 0xfc, 0xff,
0xdd, 0x9e, 0x3f, 0xf0, 0xff, 0xff, 0xf8, 0xff, 0xcf, 0x8e, 0x7f, 0xf9, 0xff, 0xff, 0xf9, 0xff,
0xcf, 0xee, 0x7f, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xcf, 0xfe, 0x7b, 0xff, 0xff, 0xff, 0xc3, 0xff,
0xe7, 0xfe, 0x78, 0xff, 0xff, 0xff, 0x07, 0xff, 0xe3, 0xfc, 0x7c, 0x3f, 0xff, 0xfc, 0x0f, 0xff,
0xf9, 0xf8, 0x7f, 0x03, 0xff, 0xc0, 0xbf, 0xff, 0xf8, 0x00, 0x7f, 0x80, 0x00, 0x01, 0xff, 0xff,
0xfe, 0x07, 0x3f, 0xfc, 0x00, 0x03, 0xff, 0xff, 0xff, 0xff, 0x1f, 0xff, 0x8f, 0xe3, 0xff, 0xff,
0xff, 0xff, 0x0f, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 0xff, 0x07, 0xff, 0xff, 0xe7, 0xff, 0xff,
0xff, 0xff, 0xc3, 0xff, 0xff, 0xc7, 0xff, 0xff, 0xff, 0xff, 0xf1, 0xff, 0xff, 0x8f, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x1f, 0xfc, 0x3f, 0xfe, 0x0f, 0xff, 0xff, 0x00, 0x00, 0x00, 0x7f, 0xfc, 0x01,
0xff, 0xf0, 0x00, 0x00, 0x00, 0x7f, 0xfc, 0xf0, 0xff, 0xc0, 0x00, 0x00, 0x00, 0x7f, 0xf9, 0xfc,
0xff, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xfb, 0xfc, 0xfc, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xf0, 0xfe,
0xfc, 0x00, 0x00, 0x00, 0x00, 0x0f, 0xe0, 0xce, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x07, 0xe0, 0xce,
0xf0, 0x00, 0x00, 0x00, 0x00, 0x07, 0xc0, 0x8e, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x17, 0xc0, 0x06,
0xf0, 0x00, 0x38, 0x00, 0x00, 0x13, 0xe0, 0x00, 0xf0, 0x07, 0xf8, 0x00, 0x00, 0x1b, 0xe1, 0xf0,
0xf0, 0x0f, 0xf0, 0x00, 0x00, 0x09, 0xc7, 0xf8, 0xe0, 0x0f, 0xc0, 0x00, 0x00, 0x0d, 0xe7, 0xf8,
0xe0, 0x0f, 0xc0, 0x00, 0x00, 0x0c, 0xe3, 0xf0, 0xe0, 0x0f, 0xc0, 0x00, 0x00, 0x0c, 0x73, 0xe2,
0xe0, 0x0f, 0xc0, 0x00, 0x00, 0x0e, 0x63, 0xc7, 0xe0, 0x07, 0x80, 0x00, 0x00, 0x06, 0x01, 0xff,
0xf0, 0x03, 0x80, 0x00, 0x00, 0x06, 0x00, 0xff, 0xf0, 0x01, 0x80, 0x00, 0x00, 0x06, 0x00, 0x7f,
0xf0, 0xe0, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0xe3, 0xfc, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00,
0xe7, 0xfe, 0x00, 0x00, 0x00, 0x03, 0x80, 0x00, 0xcf, 0xff, 0x80, 0x00, 0x00, 0x03, 0x80, 0x7f,
0xcf, 0xff, 0x80, 0x00, 0x00, 0x03, 0x80, 0x7f, 0x8f, 0xff, 0x80, 0x00, 0x00, 0x03, 0xc0, 0xff,
0x1f, 0xff, 0x00, 0x00, 0x00, 0x03, 0xe1, 0xff, 0x1f, 0xff, 0x00, 0x00, 0x1e, 0x03, 0xff, 0xff,
0x1f, 0xff, 0x00, 0x00, 0x03, 0xc7, 0xff, 0xff, 0x1f, 0xff, 0x00, 0x00, 0x01, 0xc7, 0xff, 0xff,
0x1f, 0xff, 0x00, 0x00, 0x00, 0xc7, 0xff, 0xff, 0x37, 0xfe, 0x04, 0x00, 0x00, 0x4f, 0xff, 0xff,
0xa7, 0xde, 0x0f, 0x00, 0x00, 0x7f, 0xff, 0xff, 0x83, 0xcf, 0x0f, 0x80, 0x00, 0x7f, 0xff, 0xff,
0xc3, 0xef, 0x0f, 0xe8, 0x00, 0x3f, 0xff, 0xff, 0xc0, 0x03, 0x1f, 0xff, 0x80, 0x3f, 0xff, 0xff,
0xe0, 0x00, 0x3f, 0x07, 0xc0, 0x3f, 0xff, 0xff, 0xf0, 0x00, 0x7f, 0x01, 0xc0, 0x3f, 0xff, 0xff,
0xf8, 0x7f, 0xff, 0x01, 0xc0, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0x01, 0x80, 0x3f, 0xff, 0xff,
0xff, 0xff, 0xff, 0x01, 0x80, 0x07, 0xff, 0xff, 0xff, 0xff, 0xff, 0x01, 0xc0, 0x00, 0x07, 0xff,
0xff, 0xff, 0xfe, 0x03, 0xc0, 0x00, 0x03, 0xff, 0xff, 0xff, 0xfe, 0x03, 0x80, 0x3f, 0xf1, 0xff,
0xff, 0xff, 0xfe, 0x03, 0x1f, 0xff, 0xf8, 0xff, 0xff, 0xff, 0xfe, 0x07, 0xff, 0xff, 0xfe, 0x3f,
0xff, 0xff, 0xfc, 0x07, 0xff, 0xff, 0xff, 0x1f, 0xff, 0xff, 0xf8, 0x0f, 0xff, 0xff, 0xff, 0x9f,
0xff, 0xff, 0x80, 0x0f, 0xff, 0xff, 0xfe, 0x1f, 0xff, 0xfc, 0x00, 0x08, 0xff, 0xff, 0xfe, 0x1f,
0xff, 0xfc, 0x00, 0x10, 0x7c, 0x07, 0xc6, 0x1f, 0xff, 0xfb, 0x80, 0x3f, 0x00, 0x03, 0xe2, 0x7f,
0xff, 0xfb, 0xde, 0xff, 0x80, 0x01, 0xf0, 0x7f, 0xff, 0xf9, 0xff, 0xff, 0xfe, 0x18, 0xf0, 0x7f,
0xff, 0xf9, 0xff, 0xff, 0xfe, 0x1c, 0x70, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfe, 0x0f, 0x01, 0xff,
0xff, 0xfc, 0xff, 0xff, 0xff, 0x0f, 0x83, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x87, 0x1f, 0xc7, 0xff,
0xff, 0xfe, 0x3f, 0xff, 0x80, 0x3f, 0xff, 0xff, 0xff, 0xff, 0x0f, 0xff, 0xf0, 0x7f, 0xff, 0xff,
0xff, 0xff, 0x83, 0xff, 0xf8, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xe0, 0x7f, 0xf8, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf8, 0x03, 0xf1, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x07, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xf0, 0x07, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x3f, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
},
// 'monkey03, 64x128px
{   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0x1f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x0f, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0x0f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x07, 0xf3, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0x03, 0xe3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x83, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf8, 0x00, 0x03, 0xff, 0xff, 0xff, 0xff, 0xff, 0x80, 0x00, 0x07, 0xff, 0xff, 0xff,
0xff, 0xff, 0x00, 0x00, 0x03, 0x87, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x01, 0x01, 0xff, 0xff,
0xff, 0xff, 0x00, 0x07, 0x00, 0x78, 0xff, 0xff, 0xff, 0xff, 0x80, 0x1f, 0xc0, 0xf8, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x3f, 0xe1, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x7f, 0xf3, 0xfe, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x7f, 0xe3, 0xfe, 0x7f, 0xff, 0xff, 0xfe, 0x70, 0xff, 0xbf, 0xfe, 0x7f, 0xff,
0xff, 0xe0, 0x20, 0xff, 0x1f, 0x3e, 0x7f, 0xff, 0xff, 0xc3, 0x80, 0xfe, 0x1e, 0x3e, 0x17, 0xff,
0xff, 0x8f, 0xe0, 0xfe, 0x0e, 0x1e, 0x08, 0x3f, 0xff, 0x3f, 0xe0, 0x7e, 0x0e, 0x1f, 0x3f, 0xcf,
0xff, 0x3c, 0x20, 0x7e, 0x0e, 0x1f, 0xff, 0xef, 0xff, 0x78, 0x40, 0x3e, 0x0e, 0x1f, 0xff, 0xef,
0xfe, 0x70, 0xe0, 0x1c, 0x0e, 0x1f, 0xff, 0xe7, 0xfe, 0x60, 0xe0, 0x7c, 0x0e, 0x1f, 0xff, 0xe7,
0xfe, 0x64, 0x60, 0xfe, 0x0e, 0x1f, 0xe3, 0x0f, 0xfc, 0x7c, 0x71, 0xff, 0x1e, 0x3f, 0xc0, 0x0f,
0xfe, 0x7c, 0x71, 0xff, 0x9e, 0x7f, 0xdc, 0x0f, 0xfe, 0x7f, 0x73, 0xff, 0xff, 0xff, 0xfe, 0xcf,
0xfe, 0x7f, 0xf9, 0x9f, 0xff, 0xff, 0xff, 0xcf, 0xfe, 0x7f, 0xf9, 0xcf, 0xff, 0xff, 0xff, 0x8f,
0xff, 0x3f, 0xf1, 0xc1, 0xff, 0xff, 0xff, 0x9f, 0xff, 0x87, 0xf1, 0xf0, 0xff, 0xff, 0xfe, 0x1f,
0xff, 0xe0, 0x01, 0xf8, 0x06, 0x7f, 0xfc, 0x1f, 0xff, 0xff, 0x71, 0xfc, 0x00, 0x00, 0x00, 0x7f,
0xff, 0xff, 0xf1, 0xff, 0xfc, 0x00, 0x00, 0xff, 0xff, 0xff, 0xf8, 0xff, 0xff, 0xff, 0x0f, 0xff,
0xff, 0xff, 0xf8, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xfc, 0x7f, 0xff, 0xff, 0x3f, 0xff,
0xff, 0xff, 0xfe, 0x0f, 0xff, 0xfe, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0x06, 0x1f, 0xf0, 0x7f, 0xff,
0xff, 0xff, 0xff, 0x00, 0x00, 0x01, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x07, 0xff, 0xff,
0xff, 0xff, 0xf8, 0x00, 0x00, 0x1f, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x1f, 0xff, 0xff,
0xff, 0xff, 0xe0, 0x00, 0x00, 0x0f, 0xff, 0xff, 0xff, 0xff, 0x80, 0x00, 0x00, 0x07, 0xff, 0xff,
0xff, 0xff, 0x00, 0x00, 0x00, 0x07, 0xff, 0xff, 0xff, 0xfe, 0x00, 0x00, 0x00, 0x03, 0xff, 0xff,
0xff, 0xfc, 0x00, 0x00, 0x00, 0x03, 0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x00, 0x01, 0xff, 0xff,
0xff, 0xf0, 0x03, 0x00, 0x00, 0x01, 0xf8, 0x1f, 0xff, 0xe0, 0x07, 0x00, 0x00, 0x00, 0xc3, 0x8f,
0xff, 0xe0, 0x1e, 0x00, 0x00, 0x00, 0xc3, 0xe7, 0xff, 0xc0, 0x1c, 0x18, 0x00, 0x00, 0xf1, 0xe3,
0xff, 0xc0, 0x30, 0x1f, 0x00, 0x00, 0xf8, 0xf3, 0xff, 0xc0, 0x60, 0x03, 0x80, 0x00, 0xfc, 0x73,
0xff, 0x80, 0xe3, 0x83, 0xc0, 0x00, 0x3e, 0x73, 0xff, 0x81, 0xc7, 0xff, 0xc0, 0x00, 0x3e, 0x73,
0xff, 0x00, 0xcf, 0xff, 0x80, 0x00, 0x1c, 0x67, 0xff, 0x00, 0x4f, 0xff, 0x80, 0x00, 0x9c, 0x07,
0xff, 0x00, 0x0f, 0xff, 0x20, 0x00, 0xc8, 0x07, 0xff, 0x00, 0x0f, 0xff, 0xe0, 0x01, 0xc0, 0xc7,
0xff, 0x00, 0x0f, 0xff, 0xe0, 0x01, 0xe7, 0xcf, 0xff, 0x80, 0x0f, 0xff, 0xc0, 0x01, 0xe3, 0x0f,
0xff, 0xc0, 0x0f, 0xfe, 0x00, 0x01, 0xf0, 0x0f, 0xff, 0xe0, 0x07, 0xfe, 0x00, 0x00, 0x77, 0x8f,
0xff, 0xf8, 0x07, 0xff, 0x80, 0x02, 0x03, 0x8f, 0xff, 0xf8, 0x0f, 0xff, 0x00, 0x03, 0x00, 0x1f,
0xff, 0xff, 0xc7, 0xfe, 0x00, 0x07, 0xf8, 0x3f, 0xff, 0xff, 0xe0, 0x00, 0x01, 0x83, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x00, 0x07, 0x83, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x00, 0x7f, 0x03, 0xff, 0xff,
0xff, 0xff, 0xfc, 0x00, 0x3e, 0x03, 0xff, 0xff, 0xff, 0xff, 0x3f, 0x00, 0x3c, 0x03, 0xff, 0xff,
0xff, 0xfc, 0x07, 0x80, 0x3c, 0x03, 0xff, 0xff, 0xff, 0xf9, 0xc3, 0x80, 0x1c, 0x03, 0xff, 0xff,
0xff, 0xfb, 0xe1, 0xc0, 0x1c, 0x07, 0xff, 0xff, 0xff, 0xf3, 0xe0, 0xc0, 0x18, 0x03, 0xff, 0xff,
0xff, 0xe7, 0xe0, 0x40, 0x00, 0x03, 0xff, 0xff, 0xff, 0xef, 0xc0, 0x00, 0x00, 0x07, 0xff, 0xff,
0xff, 0xcf, 0xc0, 0x00, 0x10, 0x0f, 0xff, 0xff, 0xff, 0xcf, 0xc0, 0x00, 0x30, 0x0f, 0xff, 0xff,
0xff, 0x9f, 0xc0, 0x00, 0x70, 0x0f, 0xff, 0xff, 0xff, 0x9f, 0xc0, 0x00, 0x70, 0x0f, 0xff, 0xff,
0xff, 0x9f, 0xe0, 0x00, 0xe0, 0x0f, 0xff, 0xff, 0xff, 0x3f, 0xf0, 0x07, 0xe0, 0x0f, 0xff, 0xff,
0xff, 0x3f, 0xfe, 0x3f, 0xe0, 0x1f, 0xff, 0xff, 0xff, 0x3f, 0xff, 0x3f, 0xe0, 0x1f, 0xff, 0xff,
0xff, 0x3f, 0xff, 0x3f, 0xc0, 0x3f, 0xff, 0xff, 0xff, 0x3f, 0xef, 0x3f, 0x80, 0x3f, 0xff, 0xff,
0xff, 0x3f, 0xef, 0x3f, 0x80, 0x3f, 0xff, 0xff, 0xff, 0x3f, 0xe7, 0x1f, 0x00, 0x7f, 0xff, 0xff,
0xff, 0xbc, 0xe7, 0x3e, 0x00, 0xff, 0xff, 0xff, 0xff, 0xbc, 0xe7, 0x9e, 0x00, 0xff, 0xff, 0xff,
0xff, 0x9c, 0xe7, 0xbc, 0x00, 0x4f, 0xff, 0xff, 0xff, 0x80, 0xf3, 0x3c, 0x00, 0x00, 0x01, 0x3f,
0xff, 0xc0, 0x60, 0x78, 0x03, 0xfe, 0x07, 0x8f, 0xff, 0xc6, 0x05, 0xf0, 0x03, 0xff, 0xff, 0xc7,
0xff, 0xff, 0x0f, 0xf3, 0x1f, 0xff, 0xf9, 0xe7, 0xff, 0xff, 0x3f, 0xe3, 0xff, 0xf0, 0x18, 0xc7,
0xff, 0xff, 0xff, 0xe7, 0xff, 0xf0, 0x0c, 0x4f, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xce, 0x0f,
0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xcc, 0x0f, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0x88, 0x3f,
0xff, 0xff, 0xff, 0xe0, 0x8b, 0x3f, 0x00, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x00, 0x0c, 0x03, 0xff,
0xff, 0xff, 0xff, 0xff, 0xc0, 0x00, 0x47, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe1, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
},
// 'monkey04, 64x128px
{   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc1, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xc0, 0xf8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe0, 0x78, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xe0, 0x30, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe0, 0x00, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xe0, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe0, 0x00, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xff, 0x80, 0x00, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x00, 0x00, 0x38, 0x0f, 0xff, 0xff,
0xff, 0xf8, 0x00, 0x00, 0x07, 0xe7, 0xff, 0xff, 0xff, 0xf0, 0x00, 0xf8, 0x0f, 0xe3, 0xff, 0xff,
0xff, 0xf8, 0x03, 0xfc, 0x1f, 0xf3, 0xff, 0xff, 0xff, 0xff, 0x03, 0xfe, 0x3f, 0xf3, 0xff, 0xff,
0xff, 0xff, 0x07, 0xff, 0x3f, 0xf3, 0xff, 0xff, 0xff, 0xfe, 0x07, 0xff, 0x7f, 0xfb, 0xff, 0xff,
0xff, 0xfe, 0x07, 0xf3, 0xf3, 0xfb, 0xff, 0xff, 0xff, 0xfe, 0x07, 0xe1, 0xe1, 0xf9, 0x0f, 0xff,
0xff, 0x80, 0x03, 0xe0, 0xe1, 0xf0, 0x03, 0xff, 0xff, 0x00, 0x07, 0xe0, 0xe0, 0xf1, 0xf9, 0xff,
0xfe, 0x00, 0x07, 0xe0, 0xe0, 0xff, 0xfe, 0xff, 0xfc, 0x7c, 0x07, 0xc0, 0xe1, 0xff, 0xfe, 0x7f,
0xf9, 0xf6, 0x07, 0xe0, 0xc1, 0xff, 0xfe, 0x7f, 0xfb, 0x86, 0x07, 0xe0, 0xc1, 0xff, 0xfe, 0x7f,
0xf3, 0x0f, 0x0f, 0xe0, 0xc1, 0xff, 0x30, 0x7f, 0xf2, 0x0f, 0x1f, 0xe0, 0xe1, 0xfe, 0x00, 0x7f,
0xe6, 0x0f, 0x3f, 0xf0, 0xe3, 0xfc, 0xce, 0x7f, 0xe6, 0xc7, 0x3f, 0xfd, 0xff, 0xfd, 0xce, 0x7f,
0xe7, 0xe7, 0x37, 0xff, 0xff, 0xfd, 0xfe, 0x7f, 0xe7, 0xfe, 0x3b, 0xff, 0xff, 0xff, 0xfe, 0x7f,
0xe7, 0xfe, 0x7c, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xf7, 0xfe, 0x7e, 0x7f, 0xff, 0xff, 0xf1, 0xff,
0xf3, 0xfe, 0x7e, 0x37, 0xff, 0xe0, 0x83, 0xff, 0xf9, 0xf0, 0x3f, 0x80, 0x00, 0x00, 0x03, 0xff,
0xfc, 0x00, 0x3f, 0xc0, 0x00, 0x00, 0x0f, 0xff, 0xff, 0x43, 0x3f, 0xfc, 0x1f, 0x61, 0xff, 0xff,
0xff, 0xff, 0x9f, 0xff, 0xff, 0xf1, 0xff, 0xff, 0xff, 0xff, 0xcf, 0xff, 0xff, 0xf3, 0xf0, 0x7f,
0xff, 0xff, 0xcf, 0xff, 0xff, 0xe3, 0xe6, 0x3f, 0xff, 0xff, 0xe3, 0xff, 0xff, 0x87, 0xcf, 0x9f,
0xff, 0xff, 0xe0, 0x1f, 0xfe, 0x0f, 0x1f, 0x9f, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x1e, 0x03, 0xdf,
0xff, 0xff, 0xfc, 0x00, 0x00, 0x3c, 0x03, 0xdf, 0xff, 0xff, 0xfc, 0x00, 0x00, 0xf9, 0x87, 0xcf,
0xff, 0xff, 0xf8, 0x02, 0x00, 0xf3, 0x8f, 0xe7, 0xff, 0xff, 0xf8, 0x02, 0x00, 0x63, 0x3f, 0xf3,
0xff, 0xff, 0xf8, 0x02, 0x00, 0x67, 0xff, 0xf3, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x27, 0xff, 0xf3,
0xff, 0xff, 0x30, 0x01, 0x00, 0x07, 0xff, 0xe3, 0xff, 0xff, 0x31, 0x01, 0x00, 0xcf, 0xff, 0xc7,
0xff, 0xfe, 0x31, 0x01, 0x07, 0xef, 0xff, 0xe3, 0xff, 0xfe, 0x21, 0x01, 0xff, 0x8f, 0xff, 0xf3,
0xff, 0xfe, 0x21, 0x00, 0xfc, 0x0f, 0xff, 0xf3, 0xff, 0xfc, 0x31, 0x80, 0x00, 0x0f, 0xff, 0xf3,
0xff, 0xf8, 0x31, 0x80, 0x00, 0x0f, 0xff, 0xc7, 0xff, 0xf8, 0x31, 0x80, 0x00, 0x07, 0xff, 0xc7,
0xff, 0xf8, 0x30, 0xc0, 0x00, 0x07, 0xff, 0x07, 0xff, 0xfc, 0x30, 0xc0, 0x00, 0x17, 0xfe, 0x1f,
0xff, 0xfc, 0x30, 0x60, 0x03, 0xf0, 0x00, 0x3f, 0xff, 0xfe, 0x30, 0x70, 0x7f, 0xf0, 0x00, 0x7f,
0xff, 0xfe, 0x30, 0x3f, 0xff, 0x81, 0xff, 0xff, 0xff, 0xff, 0x70, 0x1f, 0xe0, 0x01, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x04, 0x00, 0x01, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x01, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x00, 0x00, 0x01, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x01, 0xff, 0xff,
0xff, 0xff, 0xe0, 0x00, 0x00, 0x03, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x03, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x00, 0x00, 0x01, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x01, 0xff, 0xff,
0xff, 0xbf, 0xf8, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfe, 0x07, 0xf8, 0x00, 0x00, 0x00, 0x7f, 0xff,
0xf0, 0x03, 0xfc, 0x00, 0x00, 0x00, 0x7f, 0xff, 0xf0, 0x01, 0xf8, 0x04, 0x00, 0x00, 0x3f, 0xff,
0xec, 0x00, 0xf8, 0x07, 0xff, 0xc0, 0x3f, 0xff, 0xfe, 0x00, 0x00, 0x0f, 0xff, 0xe0, 0x1f, 0xff,
0xfe, 0x00, 0x00, 0x0f, 0xff, 0xe0, 0x0f, 0xff, 0xde, 0x00, 0x00, 0x0f, 0xff, 0xf8, 0x0f, 0xff,
0xde, 0x00, 0x00, 0x1f, 0xff, 0xf8, 0x0f, 0xff, 0xdf, 0x00, 0x00, 0x1f, 0xff, 0xf8, 0x07, 0xfc,
0xdf, 0xc0, 0x00, 0x3f, 0xff, 0xfc, 0x07, 0xf8, 0xdf, 0xe0, 0x00, 0x3f, 0xff, 0xfc, 0x07, 0xf8,
0xdf, 0xf8, 0x00, 0x7f, 0xff, 0xfe, 0x07, 0xf2, 0x9f, 0xfc, 0x00, 0x7f, 0xff, 0xfe, 0x03, 0xf0,
0x9f, 0xfc, 0x01, 0xff, 0xff, 0xfe, 0x03, 0xf0, 0x9f, 0xfe, 0x7f, 0xff, 0xff, 0xfe, 0x03, 0xe0,
0x9f, 0xfe, 0x7f, 0xff, 0xff, 0xff, 0x03, 0xe6, 0xdf, 0xff, 0x3f, 0xff, 0xff, 0xff, 0x03, 0xc6,
0xdf, 0xfd, 0x9f, 0xff, 0xff, 0xff, 0x03, 0xce, 0xdf, 0xfc, 0x9f, 0xff, 0xff, 0xff, 0x03, 0x8f,
0x9f, 0xdc, 0xcf, 0xff, 0xff, 0xfe, 0x00, 0x1f, 0x9f, 0xcc, 0xcf, 0xff, 0xff, 0xfe, 0x00, 0x3f,
0x9f, 0xcc, 0x0f, 0xff, 0xff, 0xfe, 0x00, 0x3f, 0xcf, 0xc6, 0x0f, 0xff, 0xff, 0xfe, 0x00, 0x7f,
0xcf, 0xe6, 0x0f, 0xff, 0xff, 0xfc, 0x07, 0xff, 0xcf, 0xe2, 0x0f, 0xff, 0xff, 0xfc, 0x7f, 0xff,
0xcf, 0xe2, 0x1f, 0xff, 0xff, 0xf8, 0xff, 0xff, 0xe7, 0xe0, 0x7f, 0xff, 0xff, 0xf9, 0xff, 0xff,
0xe7, 0xe0, 0xff, 0xff, 0xff, 0xf8, 0xff, 0xfe, 0xe3, 0xe1, 0xff, 0xff, 0xff, 0xfc, 0x7f, 0xf8,
0xf0, 0xc3, 0xff, 0xff, 0xff, 0xfc, 0x00, 0x00, 0xf8, 0x0f, 0xff, 0xff, 0xff, 0xfe, 0x00, 0x00,
0xfe, 0x3f, 0xff, 0xff, 0xff, 0xff, 0x80, 0x1f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
},
// 'monkey05, 64x128px
{   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xe3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe1, 0xfe, 0x1f, 0xff, 0xff, 0xff, 0xff,
0xff, 0xe0, 0x7c, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe0, 0x10, 0x3f, 0xff, 0xff, 0xff, 0xff,
0xff, 0xe0, 0x00, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe0, 0x00, 0x3f, 0xff, 0xff, 0xff, 0xff,
0xff, 0xe0, 0x00, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc0, 0x00, 0x08, 0x3f, 0xff, 0xff, 0xff,
0xfc, 0x00, 0x00, 0x00, 0x0f, 0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x01, 0xc7, 0xff, 0xff, 0xff,
0xf0, 0x00, 0xfc, 0x07, 0xe3, 0xff, 0xff, 0xff, 0xf8, 0x00, 0xfe, 0x0f, 0xf3, 0xff, 0xff, 0xff,
0xff, 0xc1, 0xff, 0x8f, 0xf3, 0xff, 0xff, 0xff, 0xff, 0xc3, 0xff, 0xdf, 0xf1, 0x97, 0xff, 0xff,
0xff, 0x83, 0xff, 0xd8, 0xf9, 0x03, 0xff, 0xff, 0xc3, 0x83, 0xf1, 0xf8, 0xf0, 0x00, 0xff, 0xff,
0x01, 0x03, 0xf0, 0xf0, 0x70, 0x7c, 0x7f, 0xff, 0x7c, 0x07, 0xe0, 0xf0, 0x71, 0xfe, 0x3f, 0xff,
0xff, 0x07, 0xe0, 0x70, 0x73, 0xfe, 0x3f, 0xff, 0xf7, 0x03, 0xe0, 0x70, 0x7f, 0xf8, 0x3f, 0xff,
0xc3, 0x03, 0xe0, 0x70, 0x3e, 0x18, 0x3f, 0xff, 0x83, 0x01, 0xe0, 0x30, 0x3e, 0x03, 0x3f, 0xff,
0x0f, 0x07, 0xf0, 0x38, 0x7e, 0xe7, 0x3f, 0xff, 0x07, 0x0f, 0xf0, 0x38, 0x7c, 0xe7, 0x3f, 0xff,
0x07, 0x0f, 0xf0, 0x3c, 0x7c, 0xff, 0x3f, 0xff, 0x63, 0x8f, 0xf8, 0x7e, 0x7e, 0xfe, 0x3f, 0xff,
0x77, 0x9f, 0xfc, 0xff, 0xff, 0xfc, 0x3c, 0x1f, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xf8, 0x72, 0x0f,
0xff, 0xb8, 0xff, 0xff, 0xff, 0xf0, 0xe7, 0x83, 0xff, 0x3c, 0x3f, 0xff, 0xff, 0xe0, 0xe7, 0xc0,
0xff, 0x3e, 0x0f, 0xff, 0xff, 0x81, 0xe3, 0xcc, 0x7f, 0x1f, 0x83, 0xff, 0xd0, 0x03, 0xc1, 0x9e,
0x7f, 0x1f, 0xe0, 0x00, 0x00, 0x1f, 0x81, 0xbf, 0x1e, 0x0f, 0xfe, 0x00, 0x00, 0xff, 0x81, 0xff,
0x80, 0xcf, 0xff, 0xf3, 0xf8, 0xff, 0x01, 0xfe, 0xc1, 0xef, 0xff, 0xff, 0xf9, 0xff, 0x01, 0xfe,
0xff, 0xe3, 0xff, 0xff, 0xf1, 0xfe, 0x73, 0xfe, 0xff, 0xe1, 0xff, 0xff, 0xf3, 0xfe, 0x73, 0xff,
0xff, 0xf0, 0xff, 0xff, 0x83, 0xfe, 0x7f, 0xff, 0xff, 0xfc, 0x1f, 0xfe, 0x07, 0xfe, 0x7f, 0xff,
0xff, 0xfc, 0x00, 0x00, 0x0f, 0xfe, 0x7f, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x0f, 0xfe, 0x7f, 0xff,
0xff, 0xc0, 0x00, 0x00, 0x07, 0xfe, 0x3f, 0xff, 0xff, 0x00, 0x00, 0x00, 0x03, 0xff, 0x3f, 0xfe,
0xfe, 0x00, 0x00, 0x00, 0x01, 0xff, 0x1f, 0xfe, 0xfe, 0x00, 0x00, 0x00, 0x33, 0xff, 0x83, 0xfc,
0xfe, 0x00, 0x00, 0x00, 0x1f, 0xff, 0x80, 0x40, 0xfe, 0x00, 0x00, 0x00, 0x07, 0xff, 0x80, 0x01,
0xfe, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x01, 0xfe, 0x07, 0x80, 0x00, 0x00, 0x3e, 0x00, 0x67,
0xfe, 0x03, 0x80, 0x00, 0x00, 0x00, 0x01, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xff,
0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xff, 0xff, 0x10, 0x00, 0x00, 0x00, 0x00, 0x03, 0xff,
0xfc, 0x7c, 0x00, 0x00, 0xe0, 0x00, 0x03, 0xff, 0xfc, 0x78, 0x00, 0x00, 0x70, 0x00, 0x07, 0xff,
0xf8, 0xf9, 0x80, 0x00, 0x0f, 0x00, 0x0f, 0xff, 0xf9, 0xf1, 0xc0, 0x00, 0x03, 0xfa, 0x1f, 0xff,
0xf9, 0xf3, 0xc0, 0x00, 0x00, 0x3f, 0xff, 0xff, 0xf8, 0x67, 0x80, 0x00, 0x00, 0x1f, 0xff, 0xff,
0xfc, 0x07, 0x00, 0x00, 0x00, 0x1f, 0xff, 0xff, 0xfd, 0x80, 0x00, 0x00, 0x00, 0x3f, 0xff, 0xff,
0xff, 0xe0, 0x00, 0x00, 0x00, 0x3f, 0xff, 0xff, 0xfe, 0xf3, 0x80, 0x00, 0x00, 0x0f, 0xff, 0xff,
0xfe, 0xf7, 0x80, 0x00, 0x00, 0x0f, 0xff, 0xff, 0xfe, 0xf3, 0x80, 0x00, 0x00, 0x07, 0xff, 0xff,
0xfe, 0xe3, 0xb0, 0x00, 0x00, 0x03, 0xff, 0xff, 0xfe, 0x40, 0x30, 0x00, 0x00, 0x03, 0xff, 0x00,
0xfe, 0x00, 0x30, 0x00, 0x00, 0x01, 0xff, 0x00, 0xff, 0x07, 0xf0, 0x00, 0x00, 0x00, 0xfe, 0x62,
0xff, 0xff, 0xf0, 0x00, 0x06, 0x00, 0x7e, 0x66, 0xff, 0xff, 0xf0, 0x00, 0x0f, 0x00, 0x3e, 0xe6,
0xfc, 0xff, 0xf0, 0x07, 0xff, 0x00, 0x3e, 0xcc, 0xfc, 0x3f, 0xf0, 0x0f, 0xff, 0xc0, 0x1c, 0xe4,
0xf0, 0x0f, 0xf0, 0x0f, 0xff, 0xc0, 0x1c, 0x4d, 0xe6, 0x00, 0x00, 0x0f, 0xff, 0xe0, 0x00, 0x4d,
0xe6, 0x00, 0x00, 0x0f, 0xff, 0xf0, 0x00, 0x7f, 0xce, 0x00, 0x00, 0x1f, 0xff, 0xf8, 0x00, 0x7f,
0xce, 0x00, 0x00, 0x1f, 0xff, 0xf8, 0x00, 0xff, 0x9f, 0x80, 0x00, 0x1f, 0xff, 0xfc, 0x00, 0x7f,
0x9f, 0xe0, 0x00, 0x7f, 0xff, 0xfe, 0x00, 0x7f, 0x9f, 0xf0, 0x07, 0xff, 0xff, 0xfe, 0x00, 0x3f,
0x9f, 0xf0, 0x1f, 0xff, 0xff, 0xff, 0x80, 0x3f, 0x1f, 0xff, 0x8f, 0xff, 0xff, 0xff, 0x80, 0x1f,
0x1f, 0xff, 0x87, 0xff, 0xff, 0xff, 0xc0, 0x0f, 0x1f, 0xfe, 0x03, 0xff, 0xff, 0xff, 0xe0, 0x07,
0x3f, 0xf4, 0x43, 0xff, 0xff, 0xff, 0xe0, 0x07, 0x1f, 0xf8, 0xe3, 0xff, 0xff, 0xff, 0xf0, 0x0f,
0x9f, 0xfc, 0x73, 0xff, 0xff, 0xff, 0xf0, 0x0e, 0x8f, 0xfe, 0x33, 0xff, 0xff, 0xff, 0xfc, 0x1e,
0x8f, 0xff, 0x33, 0xff, 0xff, 0xff, 0xfe, 0x1e, 0xc3, 0xfe, 0x33, 0xff, 0xff, 0xff, 0xff, 0x0c,
0xc0, 0x7e, 0x27, 0xff, 0xff, 0xff, 0xff, 0x80, 0xf0, 0x00, 0x07, 0xff, 0xff, 0xff, 0xff, 0xc0,
0xf8, 0x1f, 0xef, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
},
// 'monkey06, 64x128px
{   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc7, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xc7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x87, 0xfd, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0x87, 0xc1, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x83, 0x03, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0x00, 0x07, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x07, 0xff, 0xff, 0xff, 0xff,
0xff, 0xfa, 0x00, 0x03, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x00, 0x00, 0x01, 0x01, 0xff, 0xff, 0xff,
0xfe, 0x00, 0x00, 0x00, 0x10, 0xff, 0xff, 0xff, 0xff, 0x00, 0x07, 0x00, 0xfc, 0x7f, 0xff, 0xff,
0xff, 0xf0, 0x3f, 0xc0, 0xfe, 0x7f, 0xff, 0xff, 0xff, 0xf0, 0x3f, 0xe1, 0xfe, 0x7f, 0xff, 0xff,
0xff, 0xf8, 0x7f, 0xf1, 0xfe, 0x7f, 0xff, 0xff, 0xff, 0xf8, 0x7f, 0xfb, 0xff, 0x7c, 0x7f, 0xff,
0xff, 0xf0, 0x7f, 0xff, 0x1f, 0x00, 0x1f, 0xff, 0xf8, 0x70, 0x7f, 0x3f, 0x0f, 0x00, 0x8f, 0xff,
0xe0, 0x00, 0x7e, 0x1e, 0x0f, 0x0f, 0xe7, 0xff, 0x87, 0xe0, 0x7e, 0x0e, 0x0f, 0xff, 0xe7, 0xff,
0x9f, 0xe0, 0x7e, 0x06, 0x07, 0xff, 0xe3, 0xff, 0x3f, 0x30, 0x7e, 0x06, 0x07, 0xf3, 0xc3, 0xff,
0x3c, 0x70, 0x3e, 0x06, 0x07, 0xe0, 0x07, 0xff, 0x39, 0xf0, 0xfe, 0x07, 0x07, 0xc0, 0x07, 0xff,
0x71, 0xf0, 0xff, 0x07, 0x07, 0xde, 0xe7, 0xff, 0x70, 0xf0, 0xff, 0x07, 0x8f, 0xdf, 0xe7, 0xff,
0x64, 0xf1, 0xff, 0x07, 0xcf, 0xff, 0xe7, 0xff, 0x6c, 0x73, 0xff, 0x8f, 0xff, 0xff, 0xef, 0xff,
0x7e, 0x73, 0xff, 0xff, 0xff, 0xff, 0xcf, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff,
0x7f, 0xf3, 0xcf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0x3f, 0xf3, 0xe3, 0xff, 0xff, 0xfe, 0x7f, 0x7f,
0x9f, 0xe3, 0xf0, 0x1f, 0xff, 0x80, 0x7c, 0x3f, 0x8f, 0xc3, 0xfe, 0x00, 0x00, 0x01, 0xfb, 0x9f,
0xc3, 0x81, 0xff, 0xe0, 0x00, 0x0f, 0xe7, 0x8f, 0xe0, 0x18, 0xff, 0xff, 0xff, 0x3f, 0xc3, 0xcf,
0xfe, 0xfc, 0xff, 0xff, 0xff, 0x3f, 0x91, 0xc3, 0xff, 0xfe, 0x7f, 0xff, 0xfe, 0x3f, 0x38, 0xd3,
0xff, 0xfe, 0x3f, 0xff, 0xfe, 0x7e, 0x7f, 0xf9, 0xff, 0xff, 0x0f, 0xff, 0xf0, 0xfe, 0x7f, 0xf9,
0xff, 0xff, 0x80, 0x7f, 0xc0, 0xfc, 0x7f, 0xf8, 0xff, 0xff, 0xc0, 0x00, 0x01, 0xfc, 0xff, 0xf8,
0xff, 0xff, 0xf8, 0x00, 0x01, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x00, 0x00, 0xfc, 0xff, 0xff,
0xff, 0xff, 0x00, 0x00, 0x00, 0x7e, 0xff, 0xff, 0xff, 0xfe, 0x00, 0x00, 0x00, 0x7e, 0xff, 0xfe,
0xff, 0xf8, 0x00, 0x00, 0x0c, 0x1e, 0x7f, 0xfc, 0xff, 0xf0, 0x00, 0x00, 0x07, 0x1c, 0x7f, 0xfc,
0xff, 0xe0, 0x00, 0x00, 0x03, 0xfc, 0x3f, 0xf8, 0xff, 0xe0, 0x00, 0x00, 0x01, 0xf8, 0x0f, 0xf1,
0xff, 0xe0, 0x00, 0x00, 0x00, 0xe0, 0x07, 0xe3, 0xff, 0xe0, 0x60, 0x00, 0x00, 0x00, 0x00, 0x03,
0xff, 0xe0, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x07, 0xff, 0xf0, 0xf0, 0x02, 0x00, 0x00, 0x1e, 0x1f,
0xff, 0xd1, 0x00, 0x03, 0x00, 0x00, 0x3f, 0xff, 0xff, 0xde, 0x00, 0x01, 0x80, 0x00, 0x3f, 0xff,
0xff, 0xde, 0x40, 0x01, 0xc0, 0x00, 0x7f, 0xff, 0xff, 0xce, 0xe0, 0x00, 0xe0, 0x00, 0x7f, 0xff,
0xff, 0xcd, 0xe0, 0x00, 0x70, 0x00, 0xff, 0xff, 0xff, 0xcc, 0xe0, 0x00, 0x3c, 0x01, 0xff, 0xff,
0xff, 0xe0, 0xe0, 0x00, 0x0f, 0x07, 0xff, 0xff, 0xff, 0xe4, 0xe0, 0x00, 0x01, 0xff, 0xff, 0xff,
0xff, 0xee, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, 0xf6, 0x00, 0x00, 0x00, 0x03, 0xff, 0xff,
0xff, 0xf7, 0x00, 0x00, 0x00, 0x01, 0xff, 0xff, 0xff, 0xf3, 0x80, 0x00, 0x00, 0x00, 0xff, 0xff,
0xff, 0xfb, 0xc0, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xfd, 0xc0, 0x00, 0x00, 0x00, 0x7f, 0xff,
0xff, 0xfd, 0x98, 0x00, 0x00, 0x00, 0x7f, 0xff, 0xff, 0xfe, 0x38, 0x00, 0x07, 0x00, 0x3f, 0xff,
0xff, 0xff, 0xf8, 0x02, 0x1f, 0x80, 0x1f, 0xfc, 0xff, 0xff, 0xf8, 0x03, 0xff, 0xe0, 0x1f, 0xfc,
0xff, 0xff, 0xf0, 0x03, 0xff, 0xe0, 0x0f, 0xf9, 0xff, 0xff, 0xe0, 0x03, 0xff, 0xf0, 0x07, 0xf3,
0xf8, 0x7f, 0xc0, 0x03, 0xff, 0xf0, 0x07, 0xf2, 0xe0, 0x1f, 0x80, 0x07, 0xff, 0xf8, 0x03, 0xf6,
0xc0, 0x00, 0x00, 0x07, 0xff, 0xfc, 0x03, 0xe4, 0xcc, 0x00, 0x00, 0x07, 0xff, 0xfe, 0x01, 0xe5,
0x9c, 0x00, 0x00, 0x0f, 0xff, 0xfe, 0x00, 0x67, 0x9c, 0x00, 0x00, 0x1f, 0xff, 0xff, 0x00, 0x67,
0x9c, 0x00, 0x00, 0x3f, 0xff, 0xff, 0x00, 0x0f, 0x9e, 0x00, 0x00, 0x7f, 0xff, 0xff, 0x80, 0x0f,
0x9e, 0x00, 0x01, 0xff, 0xff, 0xff, 0xc0, 0x0f, 0x9f, 0x00, 0x1f, 0xff, 0xff, 0xff, 0xc0, 0x0f,
0x9f, 0xe7, 0xc3, 0xff, 0xff, 0xff, 0xe0, 0x07, 0x8f, 0xff, 0xc1, 0xff, 0xff, 0xff, 0xe0, 0x07,
0x8f, 0xff, 0xe0, 0x7f, 0xff, 0xff, 0xf0, 0x07, 0x8f, 0xff, 0xce, 0x7f, 0xff, 0xff, 0xf0, 0x07,
0x8f, 0xfc, 0xc2, 0x7f, 0xff, 0xff, 0xf8, 0x07, 0x8f, 0xfc, 0x62, 0x7f, 0xff, 0xff, 0xfc, 0x0f,
0x8f, 0xfe, 0x30, 0x7f, 0xff, 0xff, 0xfe, 0x0f, 0xc7, 0xfe, 0x30, 0xff, 0xff, 0xff, 0xfe, 0x3e,
0xe7, 0xff, 0x31, 0xff, 0xff, 0xff, 0xfe, 0x3e, 0xe3, 0xff, 0x23, 0xff, 0xff, 0xff, 0xfe, 0x38,
0xf0, 0xff, 0x07, 0xff, 0xff, 0xff, 0xff, 0x01, 0xfc, 0x7e, 0x0f, 0xff, 0xff, 0xff, 0xff, 0x07,
0xfe, 0x00, 0x1f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xf8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
},
// 'monkey07, 64x128px
{   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xfc, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf8, 0x60, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0xff, 0xff, 0xff, 0xff,
0xff, 0xf3, 0xf0, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x40, 0x00, 0xff, 0xff, 0xff, 0xff,
0xff, 0xf8, 0x00, 0x00, 0x70, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x00, 0x3f, 0xff, 0xff,
0xff, 0xf8, 0x01, 0x80, 0x1f, 0x3f, 0xff, 0xff, 0xff, 0xfc, 0x07, 0xf0, 0x3f, 0x9f, 0xff, 0xff,
0xff, 0xfe, 0x0f, 0xf8, 0x7f, 0x9f, 0xff, 0xff, 0xff, 0xff, 0x0f, 0xfc, 0xff, 0x9f, 0xff, 0xff,
0xff, 0xff, 0x1f, 0xfe, 0xff, 0x9f, 0xff, 0xff, 0xfe, 0xde, 0x1f, 0xff, 0xff, 0x98, 0x0f, 0xff,
0xf8, 0x0e, 0x1f, 0xff, 0xc7, 0xc0, 0x07, 0xff, 0xf3, 0xc6, 0x1f, 0xcf, 0xc3, 0xc7, 0xe3, 0xff,
0xe7, 0xe6, 0x1f, 0xc7, 0xc3, 0xc7, 0xf3, 0xff, 0xef, 0xe0, 0x1f, 0x83, 0xc3, 0xdf, 0xe1, 0xff,
0xcf, 0x18, 0x1f, 0x81, 0xc1, 0xfc, 0xc1, 0xff, 0xce, 0x3c, 0x1f, 0x81, 0xc1, 0xfc, 0x09, 0xff,
0xcc, 0x7c, 0x1f, 0x81, 0xc1, 0xfb, 0x19, 0xff, 0xc8, 0x3c, 0x1f, 0x81, 0xc1, 0xfb, 0x99, 0xff,
0x9a, 0x3c, 0x3f, 0x81, 0xc1, 0xff, 0xf9, 0xff, 0xdf, 0x3c, 0x7f, 0xc1, 0xe1, 0xff, 0xf9, 0xff,
0xdf, 0xbc, 0x7f, 0xe0, 0xff, 0xff, 0xf9, 0xff, 0xdf, 0xfc, 0xff, 0xf1, 0xff, 0xff, 0xf1, 0xff,
0xcf, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xe3, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xc7, 0xff,
0xf1, 0xfc, 0xf3, 0xff, 0xff, 0xff, 0x07, 0xff, 0xf9, 0xc0, 0xf8, 0xff, 0xff, 0xfc, 0x0f, 0xff,
0xfc, 0x00, 0x7c, 0x0f, 0xff, 0xe0, 0x3f, 0xff, 0xff, 0x00, 0x7f, 0x00, 0x38, 0x01, 0xff, 0xff,
0xff, 0xfe, 0x7f, 0xf0, 0x00, 0x03, 0xff, 0xff, 0xff, 0xfe, 0x7f, 0xfc, 0x07, 0xe7, 0xff, 0xff,
0xff, 0xfe, 0x1f, 0xff, 0xff, 0xc7, 0xff, 0xff, 0xff, 0xfe, 0x1f, 0xff, 0xff, 0xcf, 0xff, 0xff,
0xff, 0xff, 0x87, 0xff, 0xff, 0x8f, 0xff, 0xff, 0xff, 0xff, 0x83, 0xff, 0xff, 0x0f, 0xff, 0xff,
0xff, 0xff, 0xe0, 0x7f, 0xf8, 0x1f, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x1f, 0xff, 0xff,
0xff, 0xff, 0xfc, 0x00, 0x00, 0x0f, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x00, 0x00, 0x04, 0xff, 0xff,
0xff, 0xff, 0xf8, 0x00, 0x00, 0x00, 0x7f, 0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x00, 0x07, 0xff,
0xff, 0xff, 0xf8, 0x00, 0x00, 0x3c, 0x61, 0xff, 0xff, 0xff, 0xf8, 0x04, 0x00, 0x3c, 0x79, 0xff,
0xff, 0xff, 0xf0, 0x04, 0x00, 0x38, 0x7d, 0xff, 0xff, 0xff, 0xf0, 0x04, 0x00, 0x77, 0xfd, 0xff,
0xff, 0xff, 0xf0, 0x04, 0x00, 0x7f, 0xfc, 0xff, 0xff, 0xff, 0xf0, 0x04, 0x00, 0x7f, 0xf8, 0xff,
0xff, 0xff, 0xe0, 0x04, 0x00, 0x7f, 0xfa, 0x7f, 0xff, 0xff, 0xe0, 0x04, 0x04, 0x7f, 0xff, 0x7f,
0xff, 0xff, 0xe0, 0x00, 0x0c, 0x7f, 0xfe, 0x7f, 0xff, 0xff, 0xe4, 0x02, 0x78, 0x7f, 0xfe, 0x7f,
0xff, 0xff, 0xe4, 0x03, 0xc0, 0x7f, 0xfc, 0x7f, 0xff, 0xff, 0xe4, 0x03, 0x00, 0x7f, 0xf8, 0x7f,
0xff, 0xff, 0xc4, 0x00, 0x00, 0x3f, 0xfe, 0x7f, 0xff, 0xff, 0xc6, 0x00, 0x00, 0x3f, 0xfc, 0xff,
0xff, 0xff, 0xe6, 0x00, 0x00, 0x1f, 0xfc, 0xff, 0xff, 0xff, 0xe2, 0x00, 0x00, 0x0f, 0xf1, 0xff,
0xff, 0xff, 0xc2, 0x00, 0x01, 0x87, 0xc3, 0xff, 0xff, 0xff, 0xc3, 0x00, 0x03, 0x80, 0x03, 0xff,
0xff, 0xff, 0xf1, 0xc0, 0x1c, 0x00, 0x1f, 0xff, 0xff, 0xff, 0xf1, 0xfe, 0x70, 0x00, 0xff, 0xff,
0xff, 0xff, 0xe0, 0x7f, 0xe0, 0x00, 0x7f, 0xff, 0xff, 0xff, 0xe0, 0x00, 0x00, 0x00, 0x3f, 0xff,
0xff, 0xff, 0xe0, 0x00, 0x00, 0x08, 0x1f, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x38, 0x0f, 0xff,
0xff, 0xff, 0xf8, 0x00, 0x00, 0xf0, 0x07, 0xff, 0xff, 0xff, 0xfc, 0x01, 0xff, 0xf8, 0x07, 0xff,
0xff, 0xff, 0xfc, 0x01, 0xff, 0xf8, 0x07, 0xff, 0xff, 0xff, 0xfc, 0x01, 0xff, 0xfc, 0x07, 0xff,
0xff, 0xff, 0xfc, 0x01, 0xff, 0xfe, 0x03, 0xff, 0xff, 0xff, 0xfc, 0x00, 0xff, 0xfc, 0x03, 0xff,
0xff, 0xff, 0xfc, 0x01, 0xfa, 0x38, 0x03, 0xff, 0xff, 0xff, 0xfc, 0x00, 0xe0, 0x00, 0x07, 0xff,
0xff, 0xff, 0xfc, 0x00, 0xe0, 0x00, 0x07, 0xff, 0xff, 0xff, 0xf0, 0x00, 0xe0, 0x00, 0x07, 0xff,
0xff, 0xff, 0xc0, 0x01, 0xe0, 0x00, 0x0f, 0xff, 0xff, 0xff, 0x00, 0x01, 0xe0, 0x00, 0x0f, 0xff,
0xff, 0xf0, 0x00, 0x01, 0xe4, 0x00, 0x1f, 0xff, 0xff, 0x00, 0x00, 0x01, 0xe7, 0x00, 0x7f, 0xff,
0xfe, 0x00, 0x00, 0x07, 0xe7, 0xe0, 0x7f, 0xff, 0xf8, 0x00, 0x00, 0x3f, 0xe7, 0xfe, 0x7f, 0xff,
0xe0, 0x00, 0x00, 0x7f, 0xe7, 0xfe, 0x3f, 0xff, 0xe0, 0x00, 0x00, 0x1f, 0xf7, 0xff, 0x3f, 0xff,
0xce, 0x00, 0x7c, 0x0f, 0xf3, 0xff, 0x3f, 0xff, 0xce, 0x00, 0xff, 0x87, 0xf3, 0xbf, 0x1f, 0xff,
0xef, 0xff, 0xff, 0x03, 0xf3, 0x9f, 0x9f, 0xff, 0xe7, 0xff, 0xf7, 0x81, 0xf3, 0x99, 0xcf, 0xff,
0xf3, 0xff, 0xe1, 0xc1, 0xf3, 0x99, 0xcf, 0xff, 0xf1, 0xff, 0xf8, 0xe1, 0xf3, 0xc8, 0xcf, 0xff,
0xf8, 0x7f, 0xfc, 0x63, 0xf9, 0xcc, 0x0f, 0xff, 0xfc, 0x3f, 0xfc, 0x67, 0xf9, 0xcc, 0x0f, 0xff,
0xfe, 0x07, 0xfc, 0x47, 0xf9, 0xc0, 0x1f, 0xff, 0xff, 0x81, 0xfc, 0x0f, 0xfc, 0x80, 0xff, 0xff,
0xff, 0xc0, 0x10, 0x1f, 0xfc, 0x0f, 0xff, 0xff, 0xff, 0xe0, 0x00, 0x3f, 0xfe, 0x3f, 0xff, 0xff,
0xff, 0xf1, 0x01, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
},
// 'monkey08, 64x128px
{   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf8, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xf8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xe0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x80, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0x80, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0xff, 0xff, 0xff,
0xff, 0xff, 0xfe, 0x00, 0x01, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x00, 0x03, 0xff, 0xff, 0xff,
0xff, 0xff, 0xc0, 0x00, 0x03, 0x83, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x31, 0xff, 0xff,
0xff, 0xff, 0x00, 0x0f, 0x80, 0x78, 0xff, 0xff, 0xff, 0xff, 0x00, 0x1f, 0xe0, 0xf8, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x3f, 0xe1, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x7f, 0xe3, 0xfe, 0xff, 0xff,
0xff, 0xff, 0xf0, 0xff, 0xf7, 0xfe, 0x7f, 0xff, 0xff, 0xff, 0xe0, 0xff, 0x3f, 0xfe, 0x7f, 0xff,
0xff, 0xff, 0x00, 0xfe, 0x1f, 0x3e, 0x7c, 0xff, 0xff, 0xf0, 0x00, 0xfe, 0x1e, 0x3e, 0x00, 0x1f,
0xff, 0xe0, 0x40, 0xfe, 0x0e, 0x1e, 0x0d, 0xcf, 0xff, 0xcf, 0xe0, 0x7e, 0x0e, 0x1f, 0xff, 0xef,
0xff, 0x9f, 0xe0, 0x3e, 0x0e, 0x1f, 0xff, 0xef, 0xff, 0x1f, 0xc0, 0x3e, 0x0e, 0x1f, 0xff, 0xf7,
0xff, 0x3c, 0xe0, 0x1c, 0x0e, 0x1f, 0xff, 0x07, 0xfe, 0x39, 0xe0, 0xfe, 0x0e, 0x1f, 0xe0, 0x07,
0xfe, 0x79, 0xe1, 0xfe, 0x1e, 0x1f, 0xc0, 0x0f, 0xfe, 0x71, 0xf1, 0xff, 0x1e, 0x3f, 0x98, 0x4f,
0xfe, 0x60, 0xf3, 0xff, 0xbf, 0x7f, 0x9f, 0xcf, 0xfe, 0x64, 0x7b, 0xbf, 0xff, 0xff, 0xbf, 0xcf,
0xff, 0x6e, 0xf9, 0xcf, 0xff, 0xff, 0xff, 0xcf, 0xfe, 0x7f, 0xf1, 0xc3, 0xff, 0xff, 0xff, 0x9f,
0xfe, 0x7f, 0xf1, 0xe1, 0xff, 0xff, 0xff, 0x1f, 0xff, 0x3f, 0xe1, 0xf0, 0x7f, 0xff, 0xfe, 0x1f,
0xff, 0x1f, 0xe1, 0xf8, 0x00, 0x30, 0x10, 0x7f, 0xff, 0x0f, 0x81, 0xff, 0x80, 0x00, 0x00, 0xff,
0xff, 0x80, 0x00, 0xff, 0xfe, 0x06, 0x0f, 0xff, 0xff, 0xc0, 0x08, 0xff, 0xff, 0xff, 0x1f, 0xff,
0xff, 0xf8, 0xfc, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xfe, 0x3f, 0xff, 0xfe, 0x7f, 0xff,
0xff, 0xff, 0xfe, 0x0f, 0xff, 0xfc, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0x02, 0x1f, 0xe0, 0xff, 0xff,
0xff, 0xff, 0xf8, 0x00, 0x00, 0x01, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x0f, 0xff, 0xff,
0xff, 0xfe, 0x00, 0x00, 0x00, 0x07, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x00, 0x07, 0xff, 0xff,
0xff, 0xe0, 0x00, 0x00, 0x00, 0x03, 0xff, 0xff, 0xff, 0xe0, 0x00, 0x00, 0x00, 0x03, 0xff, 0xff,
0xff, 0xe0, 0x00, 0x00, 0x00, 0x01, 0xff, 0xff, 0xff, 0xc0, 0x00, 0x00, 0x00, 0x01, 0xfc, 0x1f,
0xff, 0xc0, 0x10, 0x00, 0x00, 0x00, 0xe3, 0x0f, 0xff, 0x80, 0x20, 0x00, 0x00, 0x00, 0xc3, 0xe7,
0xff, 0x80, 0x60, 0x18, 0x00, 0x00, 0xf1, 0xe3, 0xff, 0x00, 0xe0, 0x1f, 0x00, 0x00, 0xf8, 0xf3,
0xff, 0x00, 0xe0, 0x03, 0x80, 0x00, 0xfc, 0x73, 0xff, 0x00, 0xe1, 0x03, 0xc0, 0x00, 0x3e, 0x73,
0xff, 0x00, 0xc7, 0x9b, 0xc0, 0x00, 0x3e, 0x73, 0xff, 0x00, 0xcf, 0xff, 0x80, 0x00, 0x3c, 0x67,
0xff, 0x00, 0xcf, 0xff, 0x80, 0x00, 0x9c, 0x07, 0xff, 0x00, 0x0f, 0xff, 0x20, 0x00, 0xc8, 0x07,
0xff, 0x00, 0x0f, 0xff, 0xe0, 0x01, 0xc0, 0xc7, 0xff, 0x00, 0x0f, 0xff, 0xe0, 0x01, 0xe7, 0xc7,
0xff, 0x80, 0x0f, 0xff, 0xc0, 0x01, 0xe7, 0x0f, 0xff, 0xc0, 0x0f, 0xff, 0x00, 0x01, 0xf0, 0x0f,
0xff, 0xe0, 0x07, 0xfe, 0x00, 0x00, 0xf2, 0x0f, 0xff, 0xf0, 0x07, 0xff, 0x00, 0x00, 0x07, 0x8f,
0xff, 0xf8, 0x0f, 0xff, 0x00, 0x03, 0x01, 0x1f, 0xff, 0xff, 0x47, 0xfe, 0x00, 0x01, 0xf0, 0x3f,
0xff, 0xff, 0xe0, 0x00, 0x00, 0x03, 0xfe, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x00, 0x01, 0xff, 0xff,
0xff, 0xff, 0xf8, 0x00, 0x00, 0x61, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x07, 0xc1, 0xff, 0xff,
0xff, 0xff, 0xfe, 0xc0, 0x7f, 0x80, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x00, 0x7f, 0x80, 0xff, 0xff,
0xff, 0xff, 0xf3, 0x80, 0x7f, 0x80, 0xff, 0xff, 0xff, 0xff, 0xe7, 0xc0, 0x7f, 0x81, 0xff, 0xff,
0xff, 0xff, 0xc6, 0xc0, 0x7f, 0x00, 0xff, 0xff, 0xff, 0xff, 0xdc, 0x40, 0x3c, 0x00, 0xff, 0xff,
0xff, 0xff, 0x9c, 0x00, 0x30, 0x00, 0xff, 0xff, 0xff, 0xff, 0x38, 0x00, 0x60, 0x00, 0xff, 0xff,
0xff, 0xff, 0x38, 0x00, 0x20, 0x01, 0xff, 0xff, 0xff, 0xff, 0x38, 0x00, 0x60, 0x03, 0xff, 0xff,
0xff, 0xfe, 0x78, 0x00, 0x60, 0x07, 0xff, 0xff, 0xff, 0xfe, 0x7c, 0x00, 0x60, 0x1f, 0xff, 0xff,
0xff, 0xfe, 0x7c, 0xc0, 0x60, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x7f, 0xc0, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xfe, 0x7f, 0xc0, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x7f, 0xc0, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xfe, 0x7f, 0xc0, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x7f, 0x80, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xfe, 0x7f, 0x80, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x7f, 0x00, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xfe, 0x7c, 0x00, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x7c, 0x00, 0x00, 0x00, 0xff, 0xff,
0xff, 0xfe, 0xfc, 0x01, 0xfe, 0x00, 0x8f, 0xff, 0xff, 0xfe, 0x7c, 0x0f, 0xff, 0xff, 0xe7, 0xff,
0xff, 0xfe, 0x79, 0xff, 0xff, 0xfc, 0xe3, 0xff, 0xff, 0xff, 0x01, 0xff, 0xf8, 0x1c, 0xe3, 0xff,
0xff, 0xff, 0x03, 0xff, 0xf8, 0x0e, 0x27, 0xff, 0xff, 0xff, 0x87, 0xff, 0xff, 0xe6, 0x07, 0xff,
0xff, 0xff, 0xf7, 0xff, 0xff, 0xe6, 0x07, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xc6, 0x0f, 0xff,
0xff, 0xff, 0xf1, 0xff, 0xdf, 0x84, 0x1f, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x0e, 0x01, 0xff, 0xff,
0xff, 0xff, 0xfe, 0x00, 0x00, 0x03, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x60, 0x7f, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
},
// 'monkey09, 64x128px
{   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x7f, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf8, 0x3e, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x3c, 0x3f, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x18, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x00, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf0, 0x00, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xf8, 0x00, 0x00, 0x38, 0x0f, 0xff, 0xff, 0xff, 0xe0, 0x00, 0x00, 0x07, 0xc7, 0xff, 0xff,
0xff, 0xf0, 0x00, 0x78, 0x0f, 0xe3, 0xff, 0xff, 0xff, 0xfc, 0x03, 0xf8, 0x1f, 0xe3, 0xff, 0xff,
0xff, 0xff, 0x03, 0xfe, 0x3f, 0xf3, 0xff, 0xff, 0xff, 0xff, 0x07, 0xfe, 0x3f, 0xf3, 0xef, 0xff,
0xff, 0xfe, 0x07, 0xff, 0x7f, 0xf9, 0x07, 0xff, 0xff, 0xfe, 0x07, 0xf7, 0xf3, 0xf8, 0x01, 0xff,
0xff, 0xc6, 0x07, 0xe1, 0xe1, 0xf8, 0xf0, 0xff, 0xfe, 0x00, 0x03, 0xe1, 0xe1, 0xf3, 0xf8, 0x7f,
0xfc, 0x38, 0x07, 0xe0, 0xe1, 0xf3, 0xfc, 0x7f, 0xf9, 0xf8, 0x07, 0xe0, 0xe0, 0xff, 0xfe, 0x7f,
0xfb, 0xfc, 0x07, 0xc0, 0xe1, 0xff, 0x3a, 0x7f, 0xf3, 0xce, 0x07, 0xe0, 0xc1, 0xfe, 0x00, 0x7f,
0xf3, 0x9e, 0x07, 0xe0, 0xc1, 0xfc, 0x80, 0x7f, 0xf3, 0x1f, 0x0f, 0xe0, 0xc1, 0xfd, 0xce, 0x7f,
0xf3, 0x4f, 0x1f, 0xe0, 0xe1, 0xfd, 0xcc, 0x7f, 0xf7, 0xcf, 0x1f, 0xf0, 0xe1, 0xf9, 0xfc, 0x7f,
0xf7, 0xc7, 0x3f, 0xfd, 0xff, 0xff, 0xfc, 0x7f, 0xf7, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xf8, 0xff,
0xf7, 0xff, 0x33, 0xff, 0xff, 0xff, 0xf1, 0xff, 0xf3, 0xfe, 0x38, 0xff, 0xff, 0xff, 0xc1, 0xff,
0xf3, 0xfe, 0x7c, 0x7f, 0xff, 0xfe, 0x03, 0xff, 0xf9, 0xfe, 0x7e, 0x3f, 0xff, 0xe0, 0x07, 0xff,
0xf8, 0xbc, 0x7f, 0x80, 0x00, 0x00, 0x1f, 0xff, 0xfe, 0x00, 0x3f, 0x80, 0x00, 0x09, 0xff, 0xff,
0xff, 0xf3, 0x3f, 0xfc, 0x1e, 0x79, 0xff, 0x81, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xf1, 0xfe, 0x1c,
0xff, 0xff, 0xcf, 0xff, 0xff, 0xf3, 0xfe, 0x7f, 0xff, 0xff, 0xc7, 0xff, 0xff, 0xe3, 0xfc, 0xff,
0xff, 0xff, 0xe3, 0xff, 0xff, 0xc7, 0xfc, 0xff, 0xff, 0xff, 0xe0, 0x1f, 0xfe, 0x07, 0xf9, 0xff,
0xff, 0xff, 0x60, 0x00, 0x80, 0x1f, 0xf1, 0xf7, 0xff, 0xf8, 0x00, 0x00, 0x00, 0x3f, 0xf3, 0xc7,
0xff, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xf7, 0x81, 0xfe, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xe7, 0xfc,
0xfc, 0x00, 0x00, 0x00, 0x00, 0x0f, 0xf7, 0xff, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x07, 0xf3, 0xff,
0xf0, 0x00, 0x00, 0x00, 0x00, 0x07, 0xf1, 0xff, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x07, 0xf8, 0x3e,
0xf0, 0x00, 0x00, 0x00, 0x00, 0x03, 0xfc, 0x0c, 0xf0, 0x01, 0xf0, 0x00, 0x00, 0x00, 0xfc, 0x00,
0xf8, 0x03, 0xf8, 0x00, 0x00, 0x00, 0x18, 0x00, 0xf8, 0x00, 0x3c, 0x00, 0x00, 0x00, 0x00, 0x06,
0xf0, 0x00, 0x0c, 0x00, 0x00, 0x03, 0x00, 0x07, 0xf8, 0x00, 0xc0, 0x00, 0x00, 0x03, 0x00, 0x07,
0xfc, 0x00, 0xf0, 0x00, 0x00, 0x03, 0x80, 0x07, 0xfc, 0x00, 0x7c, 0x00, 0x00, 0x01, 0x80, 0x07,
0xfe, 0x00, 0x7e, 0x00, 0x00, 0x01, 0x80, 0x0f, 0xfe, 0x01, 0xe6, 0x00, 0x00, 0x00, 0xc0, 0x1f,
0xfe, 0x03, 0xf0, 0x00, 0x00, 0x00, 0xe0, 0x3f, 0xfe, 0x07, 0xf8, 0x00, 0x00, 0x00, 0xf8, 0x3f,
0xfe, 0x4f, 0xf8, 0x00, 0x00, 0x00, 0x7f, 0xff, 0xfc, 0xff, 0xfc, 0x00, 0x00, 0x00, 0xff, 0xff,
0xfc, 0xff, 0xfe, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0x00, 0x00, 0x00, 0xff, 0xff,
0xfc, 0xff, 0xff, 0x00, 0x00, 0x01, 0xff, 0xff, 0xfc, 0xff, 0xfe, 0x00, 0x01, 0x00, 0xff, 0xff,
0xfc, 0xff, 0xcc, 0x00, 0x00, 0xc0, 0xff, 0xff, 0xfc, 0xff, 0xe0, 0x70, 0x00, 0x60, 0xff, 0xff,
0xfe, 0x7e, 0xf0, 0xf8, 0x00, 0x30, 0xff, 0xff, 0xff, 0x0e, 0x30, 0xfc, 0x00, 0x39, 0xff, 0xff,
0xff, 0x80, 0x01, 0xff, 0x80, 0x1f, 0xff, 0xff, 0xff, 0xe0, 0x03, 0xff, 0xc0, 0x0f, 0xff, 0xff,
0xff, 0xf8, 0x0f, 0xff, 0xe0, 0x07, 0xff, 0x8f, 0xff, 0xff, 0xb8, 0x18, 0x30, 0x07, 0xfe, 0x00,
0xff, 0xff, 0xf0, 0x00, 0x18, 0x07, 0xfe, 0x70, 0xff, 0xff, 0xb0, 0x00, 0x18, 0x03, 0xfe, 0xf0,
0xff, 0xff, 0x30, 0x00, 0x08, 0x03, 0xfe, 0xf3, 0xff, 0xff, 0x70, 0x00, 0x0c, 0x01, 0xfc, 0xf3,
0xff, 0xfe, 0x7c, 0x00, 0x06, 0x01, 0xfc, 0xfb, 0xff, 0xfe, 0xff, 0x00, 0x0e, 0x00, 0xfc, 0xfb,
0xff, 0xfc, 0xff, 0xc0, 0x0f, 0x00, 0x7c, 0xfb, 0xff, 0xfd, 0xff, 0xf0, 0x7f, 0x00, 0xfc, 0xf9,
0xff, 0xf9, 0xff, 0xf3, 0xff, 0x00, 0x7c, 0xf9, 0xff, 0xf9, 0xff, 0xf3, 0xff, 0x00, 0x3d, 0xff,
0xff, 0xf9, 0xff, 0xf3, 0xff, 0x00, 0x39, 0xff, 0xff, 0xfb, 0xff, 0xf9, 0xff, 0x00, 0x33, 0xff,
0xff, 0xfb, 0xff, 0xf9, 0xff, 0x00, 0x07, 0xff, 0xff, 0xf3, 0xff, 0xf8, 0xff, 0x80, 0x1f, 0xff,
0xff, 0xf3, 0xff, 0xfc, 0xff, 0xbf, 0xff, 0xfe, 0xff, 0xf3, 0xff, 0xfc, 0xff, 0x3f, 0xff, 0xfe,
0xff, 0xf3, 0xfb, 0x9c, 0xff, 0x3f, 0xff, 0xfe, 0xff, 0xf3, 0xf3, 0x9c, 0xff, 0x3f, 0xff, 0xfc,
0xff, 0xf3, 0xf3, 0x9c, 0xff, 0x1f, 0xff, 0xf8, 0xff, 0xf9, 0xf3, 0x9c, 0xff, 0x9f, 0xff, 0x10,
0xff, 0xf9, 0xf3, 0x9c, 0xff, 0xc2, 0x00, 0x01, 0xff, 0xfc, 0xf1, 0x8c, 0xff, 0xe0, 0x00, 0x03,
0xff, 0xfe, 0x00, 0x01, 0xff, 0xf0, 0x61, 0xff, 0xff, 0xff, 0x8e, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
},
// 'monkey10, 64x128px
{   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf1, 0xf8, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf1, 0xf0, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xf0, 0xe0, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf0, 0x41, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xe0, 0x01, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xc0, 0x01, 0xff, 0xff, 0xff, 0xff,
0xff, 0xef, 0xc0, 0x01, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe0, 0x00, 0x00, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xf0, 0x00, 0x00, 0x00, 0x7f, 0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x00, 0x3f, 0xff, 0xff,
0xff, 0xfc, 0x03, 0xe0, 0x1f, 0x1f, 0xff, 0xff, 0xff, 0xfe, 0x07, 0xf8, 0x3f, 0xcf, 0xff, 0xff,
0xff, 0xfe, 0x07, 0xfc, 0x3f, 0xce, 0x3f, 0xff, 0xff, 0xfe, 0x0f, 0xfe, 0x7f, 0xcc, 0x07, 0xff,
0xff, 0xbe, 0x0f, 0xfe, 0x67, 0xc1, 0xe3, 0xff, 0xf8, 0x1e, 0x0f, 0xff, 0xe3, 0xc7, 0xf1, 0xff,
0xf0, 0x04, 0x1f, 0xc7, 0xc3, 0xcf, 0xe3, 0xff, 0xf3, 0xc0, 0x1f, 0x83, 0xc3, 0xcf, 0xc1, 0xff,
0xe7, 0xe0, 0x1f, 0x81, 0xc1, 0xcf, 0x81, 0xff, 0xef, 0x18, 0x1f, 0x81, 0xc1, 0xfe, 0x18, 0xff,
0xc8, 0x1c, 0x0f, 0x81, 0xc1, 0xfc, 0x1c, 0xff, 0xc8, 0x7c, 0x0f, 0x81, 0xc1, 0xfd, 0xfc, 0xff,
0xc8, 0x38, 0x0f, 0x81, 0xc1, 0xfd, 0xfd, 0xff, 0xc7, 0x3c, 0x3f, 0xc1, 0xe1, 0xfb, 0xfd, 0xff,
0x8f, 0x3c, 0x3f, 0xc1, 0xe1, 0xff, 0xf9, 0xff, 0x9f, 0xbc, 0x3f, 0xc1, 0xe1, 0xff, 0xf3, 0xff,
0x9f, 0xfe, 0x7f, 0xe3, 0xff, 0xff, 0xc7, 0xff, 0xcf, 0xfc, 0xff, 0xf7, 0xff, 0xff, 0x87, 0xff,
0xe7, 0xfc, 0xff, 0xff, 0xff, 0xff, 0x0f, 0xff, 0xe1, 0xfc, 0xe1, 0xff, 0xff, 0xfc, 0x1f, 0xff,
0xf0, 0x30, 0xf8, 0x7f, 0xff, 0xe0, 0x3f, 0xff, 0xf8, 0x00, 0xfc, 0x3f, 0xff, 0x80, 0xff, 0xe0,
0xff, 0xf0, 0xff, 0x01, 0xfe, 0x00, 0xff, 0xcf, 0xff, 0xfc, 0x7f, 0xc0, 0x00, 0x03, 0xff, 0x9f,
0xff, 0xfe, 0x7f, 0xfe, 0x00, 0x47, 0xff, 0x1f, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xe7, 0xff, 0x3d,
0xff, 0xff, 0x1f, 0xff, 0xff, 0xc7, 0xff, 0x3c, 0xff, 0xff, 0x8f, 0xff, 0xff, 0xcf, 0xff, 0x38,
0xff, 0xff, 0x87, 0xff, 0xff, 0x0f, 0xfe, 0x30, 0xff, 0xff, 0xe1, 0xff, 0xfc, 0x1f, 0xfe, 0x7f,
0xff, 0xff, 0xc0, 0x3b, 0xe0, 0x3f, 0xfe, 0x7f, 0xff, 0xe0, 0x00, 0x00, 0x00, 0x3f, 0xfe, 0x7f,
0xff, 0xc0, 0x00, 0x00, 0x00, 0x0f, 0xfe, 0x3f, 0xff, 0x00, 0x00, 0x00, 0x00, 0x07, 0xfe, 0x3c,
0xfe, 0x00, 0x00, 0x00, 0x00, 0x01, 0xff, 0x08, 0xfc, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x80,
0xfc, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xe0, 0xfc, 0x00, 0x00, 0x00, 0x00, 0x02, 0x03, 0xf0,
0xf8, 0x01, 0x00, 0x00, 0x00, 0x03, 0x00, 0xf8, 0xf8, 0x03, 0xe0, 0x00, 0x00, 0x03, 0x00, 0x78,
0xf8, 0x07, 0xff, 0x80, 0x00, 0x03, 0x80, 0x00, 0xf0, 0x07, 0xff, 0x80, 0x00, 0x01, 0xc0, 0x00,
0xe0, 0x07, 0xfe, 0x00, 0x00, 0x00, 0xc0, 0x00, 0xdc, 0x01, 0xfe, 0x00, 0x00, 0x00, 0x60, 0x00,
0x9e, 0x04, 0x3e, 0x00, 0x00, 0x00, 0x60, 0x00, 0xbe, 0x0f, 0x1e, 0x00, 0x00, 0x00, 0x70, 0x00,
0x7e, 0x3f, 0x9e, 0x00, 0x00, 0x00, 0x3f, 0x80, 0x7f, 0xff, 0xce, 0x00, 0x00, 0x00, 0x3f, 0xe0,
0xff, 0xff, 0xcf, 0x00, 0x00, 0x00, 0x3f, 0xff, 0xff, 0xff, 0xe7, 0x00, 0x00, 0x00, 0x1f, 0xff,
0xff, 0xff, 0x27, 0x80, 0x00, 0x00, 0x1f, 0x3f, 0xff, 0xff, 0x27, 0x80, 0x00, 0x00, 0x3e, 0x40,
0xff, 0xff, 0x07, 0x80, 0x00, 0x00, 0x3e, 0xe6, 0xff, 0xff, 0x07, 0xc0, 0x00, 0x00, 0x3c, 0xf6,
0xff, 0xff, 0x07, 0xe0, 0x00, 0x00, 0x3d, 0xf6, 0xff, 0xff, 0x0f, 0xf0, 0x00, 0x00, 0x7c, 0xf6,
0xef, 0xff, 0x1f, 0xf8, 0x00, 0x30, 0x7c, 0xf6, 0x6f, 0xfe, 0x3f, 0xfc, 0x00, 0x11, 0xfc, 0xf6,
0x2f, 0x7e, 0x3f, 0xfe, 0x00, 0x01, 0xfc, 0xf6, 0x07, 0x3e, 0x7f, 0xff, 0x80, 0x00, 0xfc, 0xf4,
0x80, 0x00, 0x7f, 0xff, 0x80, 0x00, 0x3e, 0xf0, 0xf0, 0x00, 0xfd, 0xff, 0xc0, 0x00, 0x1e, 0xf0,
0xf8, 0x33, 0xe0, 0x7f, 0x8c, 0x00, 0x0c, 0xf1, 0xff, 0xff, 0xc0, 0x3f, 0x07, 0x00, 0x06, 0xf7,
0xff, 0xff, 0x0c, 0x3f, 0x01, 0xe0, 0x02, 0xf7, 0xff, 0xff, 0x1c, 0x3e, 0x00, 0xf8, 0x00, 0xff,
0xff, 0xff, 0x3c, 0x00, 0x00, 0xfc, 0x00, 0xff, 0xff, 0xff, 0x38, 0x00, 0x00, 0xfc, 0x00, 0xff,
0xff, 0xff, 0x78, 0x00, 0x01, 0xff, 0x00, 0xff, 0xff, 0xff, 0x78, 0x00, 0x01, 0xff, 0x80, 0xff,
0xff, 0xfe, 0x7c, 0x00, 0x03, 0xff, 0xc0, 0xff, 0xff, 0xfe, 0x7e, 0x00, 0x07, 0xff, 0xc0, 0xff,
0xff, 0xfe, 0x7f, 0x00, 0x0f, 0xff, 0xe0, 0xff, 0xff, 0xfe, 0x7f, 0xf0, 0x3f, 0xff, 0xe1, 0xff,
0xff, 0xfc, 0x7f, 0xff, 0xcf, 0xff, 0xf1, 0xff, 0xff, 0xfc, 0x7f, 0xff, 0xe7, 0xff, 0xf1, 0xff,
0xff, 0xfe, 0x7f, 0xf3, 0xf3, 0xff, 0xfc, 0xff, 0xff, 0xfe, 0x7f, 0xf0, 0x73, 0xff, 0xfc, 0xff,
0xff, 0xfe, 0x3e, 0x3e, 0x73, 0xff, 0xfc, 0x7e, 0xff, 0xfe, 0x3f, 0x1e, 0x23, 0xff, 0xfc, 0x3e,
0xff, 0xfe, 0x1f, 0x0e, 0x07, 0xff, 0xff, 0x0c, 0xff, 0xff, 0x1f, 0xce, 0x0f, 0xff, 0xff, 0xc0,
0xff, 0xff, 0x0f, 0xc6, 0x7f, 0xff, 0xff, 0xf0, 0xff, 0xff, 0xc0, 0x80, 0x7f, 0xff, 0xff, 0xff,
0xff, 0xff, 0xe0, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x1f, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
}
};


void app_main(void)
{
	SSD1306_t dev;

#if CONFIG_I2C_INTERFACE
	ESP_LOGI(TAG, "INTERFACE is i2c");
	ESP_LOGI(TAG, "CONFIG_SDA_GPIO=%d",CONFIG_SDA_GPIO);
	ESP_LOGI(TAG, "CONFIG_SCL_GPIO=%d",CONFIG_SCL_GPIO);
	ESP_LOGI(TAG, "CONFIG_RESET_GPIO=%d",CONFIG_RESET_GPIO);
	i2c_master_init(&dev, CONFIG_SDA_GPIO, CONFIG_SCL_GPIO, CONFIG_RESET_GPIO);
#endif // CONFIG_I2C_INTERFACE

#if CONFIG_SPI_INTERFACE
	ESP_LOGI(TAG, "INTERFACE is SPI");
	ESP_LOGI(TAG, "CONFIG_MOSI_GPIO=%d",CONFIG_MOSI_GPIO);
	ESP_LOGI(TAG, "CONFIG_SCLK_GPIO=%d",CONFIG_SCLK_GPIO);
	ESP_LOGI(TAG, "CONFIG_CS_GPIO=%d",CONFIG_CS_GPIO);
	ESP_LOGI(TAG, "CONFIG_DC_GPIO=%d",CONFIG_DC_GPIO);
	ESP_LOGI(TAG, "CONFIG_RESET_GPIO=%d",CONFIG_RESET_GPIO);
	spi_master_init(&dev, CONFIG_MOSI_GPIO, CONFIG_SCLK_GPIO, CONFIG_CS_GPIO, CONFIG_DC_GPIO, CONFIG_RESET_GPIO);
#endif // CONFIG_SPI_INTERFACE

#if CONFIG_FLIP
	dev._flip = true;
	ESP_LOGW(TAG, "Flip upside down");
#endif

#if CONFIG_SSD1306_128x64
	ESP_LOGI(TAG, "Panel is 128x64");
	ssd1306_init(&dev, 128, 64);
#endif // CONFIG_SSD1306_128x64
#if CONFIG_SSD1306_128x32
	ESP_LOGE(TAG, "Panel is 128x32. This demo cannot be run.");
	while(1) { vTaskDelay(1); }
#endif // CONFIG_SSD1306_128x32

	ssd1306_contrast(&dev, 0xff);
	ssd1306_clear_screen(&dev, false);
	int count = 9;
	uint8_t segs[128];
	while(1) {
		TickType_t startTick = xTaskGetTickCount();
		// 1Ticks required
		for (int page=0;page<8;page++) {
			for (int seg=0;seg<128;seg++) {
				segs[seg] =  ssd1306_rotate_byte(monkeyAnimation[count][seg*8+page]);
			}
			ssd1306_display_image(&dev, page, 0, segs, 128);
		}
#if 0
		int index = 0;
		// 26Ticks required
		for (int seg=0;seg<128;seg++) {
			for (int page=0;page<8;page++) {
				uint8_t wk[1];
				wk[0] = monkeyAnimation[count][index++];
				wk[0] = ssd1306_rotate_byte(wk[0]);
				ssd1306_display_image(&dev, page, seg, wk, 1);
			}
		}
#endif
		TickType_t endTick = xTaskGetTickCount();
		ESP_LOGD(TAG, "diffTick=%d", endTick - startTick);
		count--;
		if (count<0) count = 9;
		vTaskDelay(4);
	}
	vTaskDelay(2000 / portTICK_PERIOD_MS);
}
